#include <SDL.h>
#include <SDL_image.h>

int main(int argc, char* argv[]) {
    if (SDL_Init(SDL_INIT_VIDEO) != 0) {
        SDL_Log("SDL_Init Error: %s", SDL_GetError());
        return 1;
    }

    SDL_Window* window = SDL_CreateWindow("Image Loading Example", SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, 800, 600, SDL_WINDOW_SHOWN);
    if (!window) {
        SDL_Log("SDL_CreateWindow Error: %s", SDL_GetError());
        SDL_Quit();
        return 1;
    }

    SDL_Renderer* renderer = SDL_CreateRenderer(window, -1, SDL_RENDERER_ACCELERATED);
    if (!renderer) {
        SDL_Log("SDL_CreateRenderer Error: %s", SDL_GetError());
        SDL_DestroyWindow(window);
        SDL_Quit();
        return 1;
    }

    // 加载BMP图像
    SDL_Surface* bmpSurface = SDL_LoadBMP("example.bmp");
    if (!bmpSurface) {
        SDL_Log("SDL_LoadBMP Error: %s", SDL_GetError());
        SDL_DestroyRenderer(renderer);
        SDL_DestroyWindow(window);
        SDL_Quit();
        return 1;
    }

    SDL_Texture* bmpTexture = SDL_CreateTextureFromSurface(renderer, bmpSurface);
    if (!bmpTexture) {
        SDL_Log("SDL_CreateTextureFromSurface Error: %s", SDL_GetError());
        SDL_FreeSurface(bmpSurface);
        SDL_DestroyRenderer(renderer);
        SDL_DestroyWindow(window);
        SDL_Quit();
        return 1;
    }

    SDL_Rect bmpRect = { 100, 100, bmpSurface->w, bmpSurface->h };

    // 加载PNG图像
    SDL_Surface* pngSurface = IMG_Load("example.png");
    if (!pngSurface) {
        SDL_Log("IMG_Load Error: %s", IMG_GetError());
        SDL_DestroyTexture(bmpTexture);
        SDL_FreeSurface(bmpSurface);
        SDL_DestroyRenderer(renderer);
        SDL_DestroyWindow(window);
        SDL_Quit();
        return 1;
    }

    SDL_Texture* pngTexture = SDL_CreateTextureFromSurface(renderer, pngSurface);
    if (!pngTexture) {
        SDL_Log("SDL_CreateTextureFromSurface Error: %s", SDL_GetError());
        SDL_FreeSurface(pngSurface);
        SDL_DestroyTexture(bmpTexture);
        SDL_FreeSurface(bmpSurface);
        SDL_DestroyRenderer(renderer);
        SDL_DestroyWindow(window);
        SDL_Quit();
        return 1;
    }

    SDL_Rect pngRect = { 300, 100, pngSurface->w, pngSurface->h };

    bool quit = false;
    SDL_Event e;

    while (!quit) {
        while (SDL_PollEvent(&e) != 0) {
            if (e.type == SDL_QUIT) {
                quit = true;
            }
        }

        SDL_RenderClear(renderer);
        SDL_RenderCopy(renderer, bmpTexture, NULL, &bmpRect);
        SDL_RenderCopy(renderer, pngTexture, NULL, &pngRect);
        SDL_RenderPresent(renderer);
    }

    SDL_DestroyTexture(pngTexture);
    SDL_DestroyTexture(bmpTexture);
    SDL_FreeSurface(pngSurface);
    SDL_FreeSurface(bmpSurface);
    SDL_DestroyRenderer(renderer);
    SDL_DestroyWindow(window);
    SDL_Quit();

    return 0;
}
